<template>
  <div class="mod-config">
    <basic-container>
      <el-form :inline="true" :model="dataForm" @keyup.enter.native="getDataList()">
        <el-form-item>
          <el-button v-if="permissions.generator_finalreportofinvestigation_add" icon="el-icon-plus" type="primary"
                     @click="addOrUpdateHandle()">新增
          </el-button>
        </el-form-item>
      </el-form>

      <div class="avue-crud">
        <el-table
          :data="dataList"
          border
          v-loading="dataListLoading">
          <el-table-column
            fixed
            prop="address"
            header-align="center"
            align="center"
            label="住址或地址">
          </el-table-column>
          <el-table-column
            prop="agent"
            header-align="center"
            align="center"
            label="委托代理人">
          </el-table-column>
          <el-table-column
            prop="agentAddress"
            header-align="center"
            align="center"
            label="委托代理人住址或地址">
          </el-table-column>
          <el-table-column
            prop="agentIdCard"
            header-align="center"
            align="center"
            label="委托代理人身份证号">
          </el-table-column>
          <el-table-column
            prop="agentPhone"
            header-align="center"
            align="center"
            label="委托代理人联系电话">
          </el-table-column>
          <el-table-column
            prop="agentWorkAndPosition"
            header-align="center"
            align="center"
            label="委托代理人工作单位及职务">
          </el-table-column>
          <el-table-column
            prop="briefCase"
            header-align="center"
            align="center"
            label="简要案情">
          </el-table-column>
          <el-table-column
            prop="causeAction"
            header-align="center"
            align="center"
            label="案由">
          </el-table-column>
          <el-table-column
            prop="filingTime"
            header-align="center"
            align="center"
            label="立案时间">
          </el-table-column>
          <el-table-column
            prop="handlingOpinionsAndSuggestions"
            header-align="center"
            align="center"
            label="处理意见和建议">
          </el-table-column>
          <el-table-column
            prop="idCard"
            header-align="center"
            align="center"
            label="身份证号">
          </el-table-column>
          <el-table-column
            prop="investigationProcess"
            header-align="center"
            align="center"
            label="调查经过">
          </el-table-column>
          <el-table-column
            prop="lawEnforcementCertificateNo"
            header-align="center"
            align="center"
            label="执法证号">
          </el-table-column>
          <el-table-column
            prop="lawEnforcementOfficials"
            header-align="center"
            align="center"
            label="执法人员">
          </el-table-column>
          <el-table-column
            prop="legalRepresentative"
            header-align="center"
            align="center"
            label="法定代表人">
          </el-table-column>
          <el-table-column
            prop="party"
            header-align="center"
            align="center"
            label="当事人">
          </el-table-column>
          <el-table-column
            prop="phone"
            header-align="center"
            align="center"
            label="联系电话">
          </el-table-column>
          <el-table-column
            prop="signatureOfTheUndertaker"
            header-align="center"
            align="center"
            label="承办人签名">
          </el-table-column>
          <el-table-column
            prop="source"
            header-align="center"
            align="center"
            label="案件来源">
          </el-table-column>
          <el-table-column
            prop="workAndPosition"
            header-align="center"
            align="center"
            label="工作单位及职务">
          </el-table-column>
          <el-table-column
            fixed="right"
            header-align="center"
            align="center"
            label="操作">
            <template slot-scope="scope">
              <el-button v-if="permissions.generator_finalreportofinvestigation_edit" type="text" size="small"
                         icon="el-icon-edit" @click="addOrUpdateHandle(scope.row.id)">修改
              </el-button>
              <el-button v-if="permissions.generator_finalreportofinvestigation_del" type="text" size="small"
                         icon="el-icon-delete" @click="deleteHandle(scope.row.id)">删除
              </el-button>
              <el-button v-if="permissions.generator_finalreportofinvestigation_wordpdf" type="text" size="small"
                         icon="el-icon-download" @click="download(scope.row.id)">下载
              </el-button>
              <el-button v-if="permissions.generator_finalreportofinvestigation_wordpdf" type="text" size="small" icon="el-icon-view"
                         @click="viewPdf(scope.row.id)">预览
              </el-button>
            </template>
          </el-table-column>
        </el-table>
      </div>

      <div class="avue-crud__pagination">
        <el-pagination
          @size-change="sizeChangeHandle"
          @current-change="currentChangeHandle"
          :current-page="pageIndex"
          :page-sizes="[10, 20, 50, 100]"
          :page-size="pageSize"
          :total="totalPage"
          background
          layout="total, sizes, prev, pager, next, jumper">
        </el-pagination>
      </div>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form v-if="addOrUpdateVisible" ref="addOrUpdate" @refreshDataList="getDataList"></table-form>
    </basic-container>
  </div>
</template>

<script>
import {fetchList, delObj, createWord} from '@/api/process/finalreportofinvestigation'
import TableForm from './finalreportofinvestigation-form'
import {mapGetters} from 'vuex'
import {download, viewPdf, wordToPdf} from "@/api/process/wordcommon";

export default {
  data() {
    return {
      dataForm: {
        key: ''
      },
      dataList: [],
      pageIndex: 1,
      pageSize: 10,
      totalPage: 0,
      dataListLoading: false,
      addOrUpdateVisible: false
    }
  },
  components: {
    TableForm
  },
  created() {
    this.getDataList()
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  methods: {
    // 获取数据列表
    getDataList() {
      this.dataListLoading = true
      fetchList(Object.assign({
        current: this.pageIndex,
        size: this.pageSize
      })).then(response => {
        this.dataList = response.data.data.records
        this.totalPage = response.data.data.total
      })
      this.dataListLoading = false
    },
    // 每页数
    sizeChangeHandle(val) {
      this.pageSize = val
      this.pageIndex = 1
      this.getDataList()
    },
    // 当前页
    currentChangeHandle(val) {
      this.pageIndex = val
      this.getDataList()
    },
    // 新增 / 修改
    addOrUpdateHandle(id) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(id)
      })
    },
    // 删除
    deleteHandle(id) {
      this.$confirm('是否确认删除ID为' + id, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(function () {
        return delObj(id)
      }).then(data => {
        this.$message.success('删除成功')
        this.getDataList()
      })
    },
    //下载word
    download(id) {
      createWord(id).then(res => {
        if (res.data.code === 0) {
          download(res.data.data)
        }
      })
    },

    //预览pdf
    viewPdf(id) {
      createWord(id).then(res => {
        if (res.data.code === 0) {
          wordToPdf(res.data.data).then(res1 => {
            viewPdf(res1.data.data)
          })
        }
      })
    }
  }
}
</script>
